@@ -1,9 +1,22 @@
-def add_type_ignore_comment(line: str) -> str:
+from typing import Optional
+
+
+def add_type_ignore_comment(line: str, error_code: Optional[str]) -> str:
     # Workarounds for https://mypy.readthedocs.io/en/stable/common_issues.html#silencing-linters
+
+    type_ignore_comment = "# type: ignore"
+
+    if error_code:
+        type_ignore_comment += f"[{error_code}]"
+
     if "# noqa" in line:
-        return line.replace("# noqa", "# type: ignore # noqa", 1)
+        return line.replace("# noqa", f"{type_ignore_comment} # noqa", 1)
     content_without_crlf = line.rstrip("\r\n")
-    return content_without_crlf + "  # type: ignore" + line[len(content_without_crlf) :]
+    return (
+        content_without_crlf
+        + f"  {type_ignore_comment}"
+        + line[len(content_without_crlf) :]
+    )
 
 
 def remove_type_ignore_comment(line: str) -> str:
